@@ -25,8 +25,6 @@ import ocv_info
 import webbrowser
 
 
-
-
 def timeremaining(elapsed, percent):
     """Returns a string with the remaining time for an operation.        
        elapsed: elapsed time for the operation so far (in seconds)
@@ -96,25 +94,6 @@ def confirm_overwrite(path, window=None):
     if response ==gtk.RESPONSE_OK: return True
     else: return False
     
-def dirac_warning(window=None):
-    """
-    Displays a warning box asking the user to make sure they realise Dirac is
-    experimental.
-    Returns True if the user chooses to continue, False otherwise
-    """
-    
-    dialogue = gtk.MessageDialog(window, gtk.DIALOG_MODAL, gtk.MESSAGE_WARNING,
-                 gtk.BUTTONS_NONE, _("Dirac encoding still experimental"))
-                 
-    dialogue.format_secondary_text(_("The Dirac encoder is still experimental. \
-Files you convert with this version may not be viewable with future versions \
-of the decoder."))
-
-    dialogue.add_buttons(gtk.STOCK_CANCEL, gtk.RESPONSE_CANCEL, _("Contin_ue"), gtk.RESPONSE_OK)
-    response = dialogue.run()
-    dialogue.destroy()
-    if response==gtk.RESPONSE_OK: return True
-    else: return False
     
     
 def cancel_check(window=None):
@@ -149,6 +128,11 @@ def about_dialogue(window=None):
     dialogue.set_website(ocv_info.website)
     dialogue.set_license(ocv_info.licence) # Learn to spell, GTK!
     dialogue.set_translator_credits(_("translator-credits"))
+
+    # Let's show off our lovely SVG logo
+    logo = gtk.gdk.pixbuf_new_from_file_at_size(
+            os.path.join(ocv_info.pixmappath,"oggconvert.svg"), 128, 128)
+    dialogue.set_logo(logo)
     
     dialogue.run()
     dialogue.destroy()
